From a2e8b1aceced1eec7ad567542bd2ac0182cb4d7b Mon Sep 17 00:00:00 2001
From: Slaven Rezic <slaven@rezic.de>
Date: Thu, 14 Jun 2018 08:15:40 +0200
Subject: [PATCH] do not lock temporary files (RT #51281)

This is required on BSD systems (FreeBSD, MacOSX ...), otherwise the
test suite would hang. It is effectively a no-op on other systems
(Linux ...).
---
 t/06_pod_tidy_process_pod_queue.t |  6 +++---
 t/08_pod_tidy_tidy_files.t        | 26 ++++++++++++-------------
 t/09_podtidy.t                    | 40 +++++++++++++++++++--------------------
 3 files changed, 36 insertions(+), 36 deletions(-)

diff --git a/t/06_pod_tidy_process_pod_queue.t b/t/06_pod_tidy_process_pod_queue.t
index 40ec32c..70f5b9e 100644
--- a/t/06_pod_tidy_process_pod_queue.t
+++ b/t/06_pod_tidy_process_pod_queue.t
@@ -18,7 +18,7 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid = File::Temp->new( DIR => $dir );
+    my $tmp_valid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     $tmp_valid->flush;
@@ -36,7 +36,7 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid = File::Temp->new( DIR => $dir );
+    my $tmp_valid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     $tmp_valid->flush;
@@ -57,7 +57,7 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid = File::Temp->new( DIR => $dir );
+    my $tmp_valid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     $tmp_valid->flush;
diff --git a/t/08_pod_tidy_tidy_files.t b/t/08_pod_tidy_tidy_files.t
index 22eef42..5d773b0 100644
--- a/t/08_pod_tidy_tidy_files.t
+++ b/t/08_pod_tidy_tidy_files.t
@@ -18,8 +18,8 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -39,8 +39,8 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -61,8 +61,8 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -83,9 +83,9 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_valid2  = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid2  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_valid2 $MESSY_POD;
@@ -109,10 +109,10 @@ use Test::Pod::Tidy;
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_valid2  = File::Temp->new( DIR => $dir );
-    my $tmp_valid3  = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid2  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid3  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_valid2 $MESSY_POD;
diff --git a/t/09_podtidy.t b/t/09_podtidy.t
index 787f321..6915dc7 100644
--- a/t/09_podtidy.t
+++ b/t/09_podtidy.t
@@ -21,8 +21,8 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -38,8 +38,8 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -54,8 +54,8 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -69,8 +69,8 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -90,8 +90,8 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_invalid $INVALID_POD;
@@ -111,9 +111,9 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_valid2  = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid2  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_valid2 $MESSY_POD;
@@ -132,9 +132,9 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_valid2  = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid2  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_valid2 $MESSY_POD;
@@ -150,10 +150,10 @@ isa_ok($cmd, 'Test::Cmd');
 
 {
     my $dir = tempdir( CLEANUP => 1 );
-    my $tmp_valid   = File::Temp->new( DIR => $dir );
-    my $tmp_valid2  = File::Temp->new( DIR => $dir );
-    my $tmp_valid3  = File::Temp->new( DIR => $dir );
-    my $tmp_invalid = File::Temp->new( DIR => $dir );
+    my $tmp_valid   = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid2  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_valid3  = File::Temp->new( DIR => $dir, EXLOCK => 0 );
+    my $tmp_invalid = File::Temp->new( DIR => $dir, EXLOCK => 0 );
 
     print $tmp_valid $MESSY_POD;
     print $tmp_valid2 $MESSY_POD;
-- 
2.1.4

